@@ -1,11 +1,23 @@
 skip_if_not_installed("plumber")
 
+test_that("create plumber.R with no packages", {
+    skip_on_cran()
+    b <- board_folder(path = tmp_dir)
+    local_mocked_bindings(version_name = function(metadata) "20130104T050607Z-xxxxx", .package = "pins")
+    tmp <- tempfile()
+    vetiver_pin_write(b, v)
+    vetiver_write_plumber(b, "cars1", file = tmp)
+    expect_snapshot(
+        cat(readr::read_lines(tmp), sep = "\n"),
+        transform = redact_vetiver
+    )
+})
+
 test_that("create plumber.R with packages", {
     skip_on_cran()
     b <- board_folder(path = tmp_dir)
+    local_mocked_bindings(version_name = function(metadata) "20130204T050607Z-xxxxx", .package = "pins")
     tmp <- tempfile()
-    cars_lm <- lm(mpg ~ cyl + disp, data = mtcars)
-    v <- vetiver_model(cars_lm, "cars1")
     v$metadata$required_pkgs <- c("beepr", "janeaustenr")
     vetiver_pin_write(b, v)
     vetiver_write_plumber(b, "cars1", file = tmp)
@@ -18,9 +30,8 @@ test_that("create plumber.R with packages", {
 test_that("create plumber.R with rsconnect = FALSE", {
     skip_on_cran()
     b <- board_folder(path = tmp_dir)
+    local_mocked_bindings(version_name = function(metadata) "20130304T050607Z-xxxxx", .package = "pins")
     tmp <- tempfile()
-    cars_lm <- lm(mpg ~ cyl + disp, data = mtcars)
-    v <- vetiver_model(cars_lm, "cars1")
     v$metadata$required_pkgs <- c("beepr", "janeaustenr")
     vetiver_pin_write(b, v)
     vetiver_write_plumber(b, "cars1", file = tmp, rsconnect = FALSE)
@@ -33,9 +44,8 @@ test_that("create plumber.R with rsconnect = FALSE", {
 test_that("create plumber.R with args in dots", {
     skip_on_cran()
     b <- board_folder(path = tmp_dir)
+    local_mocked_bindings(version_name = function(metadata) "20130404T050607Z-xxxxx", .package = "pins")
     tmp <- tempfile()
-    cars_lm <- lm(mpg ~ cyl + disp, data = mtcars)
-    v <- vetiver_model(cars_lm, "cars1")
     v$metadata$required_pkgs <- c("beepr", "janeaustenr")
     vetiver_pin_write(b, v)
     vetiver_write_plumber(b, "cars1",
@@ -46,17 +56,3 @@ test_that("create plumber.R with args in dots", {
         transform = redact_vetiver
     )
 })
-
-test_that("create plumber.R with no packages", {
-    skip_on_cran()
-    b <- board_folder(path = tmp_dir)
-    tmp <- tempfile()
-    cars_lm <- lm(mpg ~ cyl + disp, data = mtcars)
-    v <- vetiver_model(cars_lm, "cars1")
-    vetiver_pin_write(b, v)
-    vetiver_write_plumber(b, "cars1", file = tmp)
-    expect_snapshot(
-        cat(readr::read_lines(tmp), sep = "\n"),
-        transform = redact_vetiver
-    )
-})
